package com.ruoyi.zongzhi.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.zongzhi.mapper.TcSafetyCountyMapper;
import com.ruoyi.zongzhi.domain.TcSafetyCounty;
import com.ruoyi.zongzhi.service.ITcSafetyCountyService;

/**
 * 安全隐患统计Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-09-20
 */
@Service
public class TcSafetyCountyServiceImpl implements ITcSafetyCountyService 
{
    @Autowired
    private TcSafetyCountyMapper tcSafetyCountyMapper;

    /**
     * 查询安全隐患统计
     * 
     * @param id 安全隐患统计主键
     * @return 安全隐患统计
     */
    @Override
    public TcSafetyCounty selectTcSafetyCountyById(Long id)
    {
        return tcSafetyCountyMapper.selectTcSafetyCountyById(id);
    }

    /**
     * 查询安全隐患统计列表
     * 
     * @param tcSafetyCounty 安全隐患统计
     * @return 安全隐患统计
     */
    @Override
    public List<TcSafetyCounty> selectTcSafetyCountyList(TcSafetyCounty tcSafetyCounty)
    {
        return tcSafetyCountyMapper.selectTcSafetyCountyList(tcSafetyCounty);
    }

    /**
     * 新增安全隐患统计
     * 
     * @param tcSafetyCounty 安全隐患统计
     * @return 结果
     */
    @Override
    public int insertTcSafetyCounty(TcSafetyCounty tcSafetyCounty)
    {
        tcSafetyCounty.setCreateTime(DateUtils.getNowDate());
        return tcSafetyCountyMapper.insertTcSafetyCounty(tcSafetyCounty);
    }

    /**
     * 修改安全隐患统计
     * 
     * @param tcSafetyCounty 安全隐患统计
     * @return 结果
     */
    @Override
    public int updateTcSafetyCounty(TcSafetyCounty tcSafetyCounty)
    {
        tcSafetyCounty.setUpdateTime(DateUtils.getNowDate());
        return tcSafetyCountyMapper.updateTcSafetyCounty(tcSafetyCounty);
    }

    /**
     * 批量删除安全隐患统计
     * 
     * @param ids 需要删除的安全隐患统计主键
     * @return 结果
     */
    @Override
    public int deleteTcSafetyCountyByIds(Long[] ids)
    {
        return tcSafetyCountyMapper.deleteTcSafetyCountyByIds(ids);
    }

    /**
     * 删除安全隐患统计信息
     * 
     * @param id 安全隐患统计主键
     * @return 结果
     */
    @Override
    public int deleteTcSafetyCountyById(Long id)
    {
        return tcSafetyCountyMapper.deleteTcSafetyCountyById(id);
    }
}
